@@ -23,10 +23,11 @@ extern SEXP cgpred(SEXP, SEXP, SEXP);
 extern SEXP cgsd(SEXP, SEXP, SEXP);
 extern SEXP check_covariance(SEXP);
 extern SEXP chow_liu(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
-extern SEXP class_err(SEXP, SEXP);
 extern SEXP classic_discrete_parameters(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP colliders(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
+extern SEXP completely_directed(SEXP, SEXP);
 extern SEXP configurations(SEXP, SEXP, SEXP);
+extern SEXP connected_components(SEXP, SEXP);
 extern SEXP count_observed_values(SEXP);
 extern SEXP cpdag(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP cpdist_lw(SEXP, SEXP, SEXP, SEXP, SEXP);
@@ -51,33 +52,33 @@ extern SEXP hierarchical_dirichlet_parameters(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP
 extern SEXP ide_cozman_graph(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP increment_test_counter(SEXP);
 extern SEXP indep_test(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
-extern SEXP is_dag(SEXP, SEXP);
+extern SEXP is_acyclic(SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP is_listed(SEXP, SEXP, SEXP, SEXP, SEXP);
-extern SEXP is_pdag_acyclic(SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP is_row_equal(SEXP, SEXP);
 extern SEXP joint_discretize(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
-extern SEXP loglikelihood_function(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
+extern SEXP loglikelihood_function(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP lw_weights(SEXP, SEXP, SEXP, SEXP);
 extern SEXP mappred(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP marginal_discretize(SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP match_brace(SEXP, SEXP, SEXP, SEXP);
 extern SEXP mean_strength(SEXP, SEXP, SEXP);
-extern SEXP minimal_data_frame(SEXP);
 extern SEXP minimal_table(SEXP, SEXP);
 extern SEXP mixture_gaussian_ols_parameters(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP naivepred(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP nbr2arcs(SEXP);
 extern SEXP normalize_cpt(SEXP);
 extern SEXP nparams_cgnet(SEXP, SEXP, SEXP);
-extern SEXP nparams_fitted(SEXP, SEXP, SEXP);
+extern SEXP nparams_fitted(SEXP, SEXP);
 extern SEXP num_arcs(SEXP);
 extern SEXP onLoad(void);
 extern SEXP onUnload(void);
 extern SEXP ordered_graph(SEXP, SEXP, SEXP);
+extern SEXP path_matrix(SEXP, SEXP);
 extern SEXP pdag_extension(SEXP, SEXP, SEXP);
 extern SEXP pdag2dag(SEXP, SEXP);
 extern SEXP per_node_score(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP rbn_master(SEXP, SEXP, SEXP, SEXP, SEXP);
+extern SEXP reachability_matrix(SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP reset_test_counter(void);
 extern SEXP root_nodes(SEXP, SEXP);
 extern SEXP roundrobin_test(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
