@@ -108,7 +108,7 @@ ddata local_data = { 0 };
 
 /* log-likelihood of a whole sample for a discrete network. */
 double data_discrete_loglikelihood(fitted_bn bn, ddata dt, bool propagate,
-    bool loss, bool debugging) {
+    bool debugging) {
 
 int max_nlvls = 0, cumdim = 0, max_cfgs = 0, *parcfgs = NULL;
 double loglik = 0, node_loglik = 0;
@@ -143,7 +143,7 @@ ddata local_data = { 0 };
     if (!dt.m.flag[i].fixed)
       continue;
 
-    if (debugging && !loss)
+    if (debugging)
       Rprintf("* processing node %s.\n", bn.labels[i]);
 
     /* ... reset the log-likelihood accumulator... */
@@ -158,7 +158,7 @@ ddata local_data = { 0 };
       /* ... if there are frequencies... */
       if (freq.nobs == 0) {
 
-        node_loglik = R_NegInf;
+        node_loglik = NA_REAL;
         goto tail_of_the_loop;
 
       }/*THEN*/
@@ -188,7 +188,7 @@ ddata local_data = { 0 };
       /* ... if there are usable locally-complete observations... */
       if (freq2.nobs == 0) {
 
-        node_loglik = R_NegInf;
+        node_loglik = NA_REAL;
         goto tail_of_the_loop;
 
       }/*THEN*/
@@ -211,19 +211,9 @@ tail_of_the_loop:
 
     if (debugging) {
 
-      if (loss) {
-
-        Rprintf("  > log-likelihood loss for node %s is %lf.\n",
-          bn.labels[i], - node_loglik / dt.m.nobs);
-
-      }/*THEN*/
-      else {
-
-        Rprintf("  > %d locally-complete observations out of %d.\n",
-          (bn.ldists[i].nparents == 0) ? freq.nobs: freq2.nobs, dt.m.nobs);
-        Rprintf("  > log-likelihood is %lf.\n", node_loglik);
-
-      }/*THEN*/
+      Rprintf("  > %d locally-complete observations out of %d.\n",
+        (bn.ldists[i].nparents == 0) ? freq.nobs: freq2.nobs, dt.m.nobs);
+      Rprintf("  > log-likelihood is %lf.\n", node_loglik);
 
     }/*THEN*/
 
